mcal package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   mcal.calculations
   mcal.utils

Submodules
----------

mcal.mcal module
----------------

.. automodule:: mcal.mcal
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: mcal
   :members:
   :undoc-members:
   :show-inheritance:
